package com.ruoyi.project.system.service;

import java.util.List;
import com.ruoyi.project.system.domain.SysPlant;

/**
 * 装置管理Service接口
 * 
 * @author ruoyi
 * @date 2021-06-23
 */
public interface ISysPlantService 
{
    /**
     * 查询装置管理
     * 
     * @param plantId 装置管理ID
     * @return 装置管理
     */
    public SysPlant selectSysPlantById(Long plantId);

    /**
     * 查询装置管理列表
     * 
     * @param sysPlant 装置管理
     * @return 装置管理集合
     */
    public List<SysPlant> selectSysPlantList(SysPlant sysPlant);

    /**
     * 新增装置管理
     * 
     * @param sysPlant 装置管理
     * @return 结果
     */
    public int insertSysPlant(SysPlant sysPlant);

    /**
     * 修改装置管理
     * 
     * @param sysPlant 装置管理
     * @return 结果
     */
    public int updateSysPlant(SysPlant sysPlant);

    /**
     * 批量删除装置管理
     * 
     * @param plantIds 需要删除的装置管理ID
     * @return 结果
     */
    public int deleteSysPlantByIds(Long[] plantIds);

    /**
     * 删除装置管理信息
     * 
     * @param plantId 装置管理ID
     * @return 结果
     */
    public int deleteSysPlantById(Long plantId);

    List<SysPlant> selectSysPlantByPlants(List plantIds);

    List<SysPlant> selectSysMyPlantList(SysPlant sysPlant);
}
